@@ -1,7 +1,5 @@
 context("get_characters")
 
-require(XML)
-require(RNeXML)
 
 f <- system.file("examples", "comp_analysis.xml", package="RNeXML")
 nex <- read.nexml(f)
@@ -47,4 +45,4 @@ test_that("get_characters throws appropriate warnings", {
   expect_that(get_characters(nex), not(gives_warning()))
   expect_that(get_characters(char_list), not(gives_warning()))
   expect_warning(get_characters(longlist, suffixes=TRUE))
-})
\ No newline at end of file
+})
